@@ -1,4 +1,4 @@
-from data.enums.healthenum import HealthEnum
+from logyca.data.enums.healthenum import HealthEnum
 
 class HealthDTO():
     '''Description
